import customtkinter as ctk
from tkinter import messagebox
from utils.api_requests import register_api

SHOPPING = "#00c1ff"
DARK_BG = "#1f1f1f"
CARD_BG = "#2b2b2b"

def register_frame(parent, switch_func, API_URL):
    # Create a full-window container with dark background
    container = ctk.CTkFrame(parent, fg_color=DARK_BG)
    container.grid_columnconfigure(0, weight=1)
    container.grid_columnconfigure(1, weight=1)
    container.grid_rowconfigure(0, weight=1)

    # Left branding frame
    left_frame = ctk.CTkFrame(container, fg_color=CARD_BG, corner_radius=15)
    left_frame.grid(row=0, column=0, sticky="nsew", padx=(20, 10), pady=20)

    # App branding
    brand_frame = ctk.CTkFrame(left_frame, fg_color="transparent")
    brand_frame.place(relx=0.5, rely=0.5, anchor="center")

    app_name = ctk.CTkLabel(
        brand_frame,
        text="Shopping App",
        font=("Helvetica", 40, "bold"),
        text_color=SHOPPING
    )
    app_name.pack()

    app_slogan = ctk.CTkLabel(
        brand_frame,
        text="Join Our Shopping Community",
        font=("Helvetica", 16),
        text_color="white"
    )
    app_slogan.pack(pady=(10, 30))

    # Right register frame
    right_frame = ctk.CTkFrame(container, fg_color=CARD_BG, corner_radius=15)
    right_frame.grid(row=0, column=1, sticky="nsew", padx=(10, 20), pady=20)

    def register():
        username = entry_username.get()
        email = entry_email.get()
        phone_number = entry_phone.get()
        password = entry_password.get()
        confirm_password = entry_confirm_password.get()

        if not all([username, email, phone_number, password, confirm_password]):
            messagebox.showwarning("Input Error", "All fields are required!")
            return

        if password != confirm_password:
            messagebox.showerror("Password Error", "Passwords do not match!")
            return

        status_code, response_data = register_api(
            username, email, phone_number, password, API_URL
        )

        if status_code == 200:
            messagebox.showinfo("Registration Successful", f"Welcome, {username}!")
            switch_func("login")
        else:
            messagebox.showerror(
                "Registration Failed", response_data.get("detail", "Unknown error")
            )

    # Register form container
    form_frame = ctk.CTkFrame(right_frame, fg_color="transparent")
    form_frame.place(relx=0.5, rely=0.5, anchor="center")

    # Title
    ctk.CTkLabel(
        form_frame,
        text="Create Account",
        font=("Helvetica", 32, "bold"),
        text_color=SHOPPING
    ).pack(pady=(0, 10))

    ctk.CTkLabel(
        form_frame,
        text="Fill in your details to register",
        font=("Helvetica", 14),
        text_color="gray"
    ).pack(pady=(0, 20))

    # Username
    username_frame = ctk.CTkFrame(form_frame, fg_color="transparent")
    username_frame.pack(fill="x", pady=(0, 15))

    ctk.CTkLabel(
        username_frame,
        text="Username",
        font=("Helvetica", 14),
        text_color="white"
    ).pack(anchor="w")

    entry_username = ctk.CTkEntry(
        username_frame,
        height=40,
        corner_radius=8,
        placeholder_text="Enter your username",
        fg_color="#3b3b3b",
        border_color=SHOPPING,
        text_color="white"
    )
    entry_username.pack(fill="x", pady=(5, 0))

    # Email
    email_frame = ctk.CTkFrame(form_frame, fg_color="transparent")
    email_frame.pack(fill="x", pady=(0, 15))

    ctk.CTkLabel(
        email_frame,
        text="Email",
        font=("Helvetica", 14),
        text_color="white"
    ).pack(anchor="w")

    entry_email = ctk.CTkEntry(
        email_frame,
        height=40,
        corner_radius=8,
        placeholder_text="Enter your email",
        fg_color="#3b3b3b",
        border_color=SHOPPING,
        text_color="white"
    )
    entry_email.pack(fill="x", pady=(5, 0))

    # Phone
    phone_frame = ctk.CTkFrame(form_frame, fg_color="transparent")
    phone_frame.pack(fill="x", pady=(0, 15))

    ctk.CTkLabel(
        phone_frame,
        text="Phone Number",
        font=("Helvetica", 14),
        text_color="white"
    ).pack(anchor="w")

    entry_phone = ctk.CTkEntry(
        phone_frame,
        height=40,
        corner_radius=8,
        placeholder_text="Enter your phone number",
        fg_color="#3b3b3b",
        border_color=SHOPPING,
        text_color="white"
    )
    entry_phone.pack(fill="x", pady=(5, 0))

    # Password
    password_frame = ctk.CTkFrame(form_frame, fg_color="transparent")
    password_frame.pack(fill="x", pady=(0, 15))

    ctk.CTkLabel(
        password_frame,
        text="Password",
        font=("Helvetica", 14),
        text_color="white"
    ).pack(anchor="w")

    entry_password = ctk.CTkEntry(
        password_frame,
        height=40,
        corner_radius=8,
        show="*",
        placeholder_text="Enter your password",
        fg_color="#3b3b3b",
        border_color=SHOPPING,
        text_color="white"
    )
    entry_password.pack(fill="x", pady=(5, 0))

    # Confirm Password
    confirm_frame = ctk.CTkFrame(form_frame, fg_color="transparent")
    confirm_frame.pack(fill="x", pady=(0, 20))

    ctk.CTkLabel(
        confirm_frame,
        text="Confirm Password",
        font=("Helvetica", 14),
        text_color="white"
    ).pack(anchor="w")

    entry_confirm_password = ctk.CTkEntry(
        confirm_frame,
        height=40,
        corner_radius=8,
        show="*",
        placeholder_text="Confirm your password",
        fg_color="#3b3b3b",
        border_color=SHOPPING,
        text_color="white"
    )
    entry_confirm_password.pack(fill="x", pady=(5, 0))

    # Register Button
    ctk.CTkButton(
        form_frame,
        text="Create Account",
        command=register,
        corner_radius=8,
        height=45,
        font=("Helvetica", 14, "bold"),
        fg_color=SHOPPING,
        hover_color="#0096ff",
    ).pack(fill="x", pady=(0, 15))

    # Login Redirect
    login_frame = ctk.CTkFrame(form_frame, fg_color="transparent")
    login_frame.pack(fill="x")

    ctk.CTkLabel(
        login_frame,
        text="Already have an account?",
        font=("Helvetica", 12),
        text_color="gray"
    ).pack(side="left", padx=(0, 5))

    ctk.CTkButton(
        login_frame,
        text="Sign In",
        command=lambda: switch_func("login"),
        fg_color="transparent",
        hover_color="#3b3b3b",
        text_color=SHOPPING,
        font=("Helvetica", 12, "bold"),
        width=70,
        height=25
    ).pack(side="left")

    return container
